/*
 * ejabberd external authentication program
 *
 * (c) Alexander Vdolainen 2013, 2018, 2019, 2021 <alex@vapaa.xyz>
 *
 * this is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * this is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.";
 *
 */

#include <stdio.h>
#include <stdint.h>
#include <unistd.h>
#include <errno.h>

#include <ejabbermsg.h>

ssize_t eport_read(FILE *stream, char *buffer, size_t buffer_size)
{
  int fd = fileno(stream);
  int16_t port_msg_len = 0;
  ssize_t pr = 0;

  if(fd < 0) return -1;

  /* firstly the size of plain text message is required.
   * it has a short size and is going in bigendian order.
   */
  pr = read(fd, &port_msg_len, sizeof(int16_t));
  if(pr < 0) return -1;
  port_msg_len = (port_msg_len << 8) | ((port_msg_len >> 8) & 0xFF);

  /* check if a buffer has required amount of bytes */
  if(port_msg_len > buffer_size) {
    errno = EMSGSIZE; /* message is too long */
    return -1;
  } else
    pr = read(fd, buffer, port_msg_len);

  return pr;
}

ssize_t eport_write(FILE *stream, char *buffer, size_t buffer_size)
{
  return -1;
}

int eport_ejabberd_msgread(char *buffer, size_t buffer_size,
                           struct ejabber_msg *m)
{
  return 0;
}
